package jdk.javadoc.internal.doclets.toolkit.resources;

public final class doclets_ja extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "doclet.Abstract_Methods", "abstract\u30E1\u30BD\u30C3\u30C9" },
            { "doclet.All_Classes", "\u3059\u3079\u3066\u306E\u30AF\u30E9\u30B9" },
            { "doclet.All_Implemented_Interfaces", "\u3059\u3079\u3066\u306E\u5B9F\u88C5\u3055\u308C\u305F\u30A4\u30F3\u30BF\u30D5\u30A7\u30FC\u30B9:" },
            { "doclet.All_Methods", "\u3059\u3079\u3066\u306E\u30E1\u30BD\u30C3\u30C9" },
            { "doclet.All_Modules", "\u3059\u3079\u3066\u306E\u30E2\u30B8\u30E5\u30FC\u30EB" },
            { "doclet.All_Packages", "\u3059\u3079\u3066\u306E\u30D1\u30C3\u30B1\u30FC\u30B8" },
            { "doclet.All_Superinterfaces", "\u3059\u3079\u3066\u306E\u30B9\u30FC\u30D1\u30FC\u30A4\u30F3\u30BF\u30D5\u30A7\u30FC\u30B9:" },
            { "doclet.All_classes_and_interfaces", "\u3059\u3079\u3066\u306E\u30AF\u30E9\u30B9\u304A\u3088\u3073\u30A4\u30F3\u30BF\u30D5\u30A7\u30FC\u30B9(\u975Estatic\u306E\u30CD\u30B9\u30C8\u3055\u308C\u305F\u578B\u3092\u9664\u304F)" },
            { "doclet.AnnotationType", "\u6CE8\u91C8\u578B" },
            { "doclet.AnnotationTypes", "\u6CE8\u91C8\u578B" },
            { "doclet.Annotation_Type_Member", "\u6CE8\u91C8\u578B\u8981\u7D20" },
            { "doclet.Annotation_Type_Member_Detail", "\u8981\u7D20\u306E\u8A73\u7D30" },
            { "doclet.Annotation_Type_Optional_Member", "\u4EFB\u610F\u8981\u7D20" },
            { "doclet.Annotation_Type_Optional_Member_Summary", "\u4EFB\u610F\u8981\u7D20\u306E\u6982\u8981" },
            { "doclet.Annotation_Type_Optional_Members", "\u4EFB\u610F\u8981\u7D20" },
            { "doclet.Annotation_Type_Required_Member", "\u5FC5\u9808\u8981\u7D20" },
            { "doclet.Annotation_Type_Required_Member_Summary", "\u5FC5\u9808\u8981\u7D20\u306E\u6982\u8981" },
            { "doclet.Annotation_Type_Required_Members", "\u5FC5\u9808\u8981\u7D20" },
            { "doclet.Annotation_Types_Summary", "\u6CE8\u91C8\u578B\u306E\u6982\u8981" },
            { "doclet.Author", "\u4F5C\u6210\u8005:" },
            { "doclet.Building_Index", "\u5168\u30D1\u30C3\u30B1\u30FC\u30B8\u3068\u30AF\u30E9\u30B9\u306E\u30A4\u30F3\u30C7\u30C3\u30AF\u30B9\u3092\u4F5C\u6210\u3057\u3066\u3044\u307E\u3059..." },
            { "doclet.Building_Index_For_All_Classes", "\u5168\u30AF\u30E9\u30B9\u306E\u30A4\u30F3\u30C7\u30C3\u30AF\u30B9\u3092\u4F5C\u6210\u3057\u3066\u3044\u307E\u3059..." },
            { "doclet.Building_Tree", "\u5168\u30D1\u30C3\u30B1\u30FC\u30B8\u3068\u30AF\u30E9\u30B9\u306E\u968E\u5C64\u30C4\u30EA\u30FC\u3092\u4F5C\u6210\u3057\u3066\u3044\u307E\u3059..." },
            { "doclet.Class", "\u30AF\u30E9\u30B9" },
            { "doclet.Class_0_extends_implements_serializable", "Class {0} extends {1} implements Serializable" },
            { "doclet.Class_0_implements_serializable", "Class {0} implements Serializable" },
            { "doclet.Class_Summary", "\u30AF\u30E9\u30B9\u306E\u6982\u8981" },
            { "doclet.Classes", "\u30AF\u30E9\u30B9" },
            { "doclet.Concealed_Packages_Summary", "\u975E\u8868\u793A" },
            { "doclet.Concrete_Methods", "concrete\u30E1\u30BD\u30C3\u30C9" },
            { "doclet.ConstantField", "\u5B9A\u6570\u30D5\u30A3\u30FC\u30EB\u30C9" },
            { "doclet.Constants_Summary", "\u5B9A\u6570\u30D5\u30A3\u30FC\u30EB\u30C9\u5024" },
            { "doclet.Constants_Table_Summary", "{0}\u8868\u3001\u5B9A\u6570\u30D5\u30A3\u30FC\u30EB\u30C9\u306E\u30EA\u30B9\u30C8\u304A\u3088\u3073\u5024" },
            { "doclet.Constructor", "\u30B3\u30F3\u30B9\u30C8\u30E9\u30AF\u30BF" },
            { "doclet.Constructor_Detail", "\u30B3\u30F3\u30B9\u30C8\u30E9\u30AF\u30BF\u306E\u8A73\u7D30" },
            { "doclet.Constructor_Summary", "\u30B3\u30F3\u30B9\u30C8\u30E9\u30AF\u30BF\u306E\u6982\u8981" },
            { "doclet.Constructors", "\u30B3\u30F3\u30B9\u30C8\u30E9\u30AF\u30BF" },
            { "doclet.Copy_Overwrite_warning", "\u30D5\u30A1\u30A4\u30EB{0}\u306F\u540C\u3058\u540D\u524D\u306E\u30D5\u30A1\u30A4\u30EB\u304C\u3042\u308B\u306E\u3067{1}\u306B\u30B3\u30D4\u30FC\u3055\u308C\u307E\u305B\u3093\u3067\u3057\u305F..." },
            { "doclet.Copying_File_0_To_Dir_1", "\u30D5\u30A1\u30A4\u30EB{0}\u3092\u30C7\u30A3\u30EC\u30AF\u30C8\u30EA{1}\u306B\u30B3\u30D4\u30FC\u4E2D..." },
            { "doclet.Copying_File_0_To_File_1", "\u30D5\u30A1\u30A4\u30EB{0}\u3092\u30D5\u30A1\u30A4\u30EB{1}\u306B\u30B3\u30D4\u30FC\u4E2D..." },
            { "doclet.Default", "\u30C7\u30D5\u30A9\u30EB\u30C8:" },
            { "doclet.DefaultValue", "\u30C7\u30D5\u30A9\u30EB\u30C8\u5024:" },
            { "doclet.Default_Methods", "\u30C7\u30D5\u30A9\u30EB\u30C8\u30FB\u30E1\u30BD\u30C3\u30C9" },
            { "doclet.Deprecated", "\u63A8\u5968\u3055\u308C\u3066\u3044\u307E\u305B\u3093\u3002" },
            { "doclet.DeprecatedForRemoval", "\u975E\u63A8\u5968\u3001\u524A\u9664\u4E88\u5B9A: \u3053\u306EAPI\u8981\u7D20\u306F\u5C06\u6765\u306E\u30D0\u30FC\u30B8\u30E7\u30F3\u3067\u524A\u9664\u4E88\u5B9A\u3067\u3059\u3002" },
            { "doclet.Deprecated_Methods", "\u63A8\u5968\u3055\u308C\u3066\u3044\u306A\u3044\u30E1\u30BD\u30C3\u30C9" },
            { "doclet.Description", "\u8AAC\u660E" },
            { "doclet.Encoding_not_supported", "\u30A8\u30F3\u30B3\u30FC\u30C7\u30A3\u30F3\u30B0{0}\u306F\u30B5\u30DD\u30FC\u30C8\u3055\u308C\u3066\u3044\u307E\u305B\u3093" },
            { "doclet.Enum", "\u5217\u6319" },
            { "doclet.Enum_Constant", "\u5217\u6319\u578B\u5B9A\u6570" },
            { "doclet.Enum_Constant_Detail", "\u5217\u6319\u578B\u5B9A\u6570\u306E\u8A73\u7D30" },
            { "doclet.Enum_Constant_Summary", "\u5217\u6319\u578B\u5B9A\u6570\u306E\u6982\u8981" },
            { "doclet.Enum_Constants", "\u5217\u6319\u5B9A\u6570" },
            { "doclet.Enum_Summary", "\u5217\u6319\u578B\u306E\u6982\u8981" },
            { "doclet.Enums", "\u5217\u6319" },
            { "doclet.Error", "\u30A8\u30E9\u30FC" },
            { "doclet.Error_Summary", "\u30A8\u30E9\u30FC\u306E\u6982\u8981" },
            { "doclet.Error_invalid_custom_tag_argument", "\u30A8\u30E9\u30FC - {0}\u306F-tag\u30AA\u30D7\u30B7\u30E7\u30F3\u306B\u5BFE\u3057\u3066\u7121\u52B9\u306A\u5F15\u6570\u3067\u3059..." },
            { "doclet.Error_taglet_not_registered", "\u30A8\u30E9\u30FC - \u30BF\u30B0\u30EC\u30C3\u30C8{1}\u3092\u767B\u9332\u3057\u3088\u3046\u3068\u3057\u3066\u3044\u308B\u3068\u304D\u306B\u3001\u4F8B\u5916{0}\u304C\u30B9\u30ED\u30FC\u3055\u308C\u307E\u3057\u305F..." },
            { "doclet.Errors", "\u30A8\u30E9\u30FC" },
            { "doclet.Exception", "\u4F8B\u5916" },
            { "doclet.Exception_Summary", "\u4F8B\u5916\u306E\u6982\u8981" },
            { "doclet.Exceptions", "\u4F8B\u5916" },
            { "doclet.ExportedTo", "\u30E2\u30B8\u30E5\u30FC\u30EB\u306B\u30A8\u30AF\u30B9\u30DD\u30FC\u30C8" },
            { "doclet.Exported_Packages_Summary", "\u30A8\u30AF\u30B9\u30DD\u30FC\u30C8" },
            { "doclet.Factory", "\u30D5\u30A1\u30AF\u30C8\u30EA:" },
            { "doclet.Field", "\u30D5\u30A3\u30FC\u30EB\u30C9" },
            { "doclet.Field_Detail", "\u30D5\u30A3\u30FC\u30EB\u30C9\u306E\u8A73\u7D30" },
            { "doclet.Field_Summary", "\u30D5\u30A3\u30FC\u30EB\u30C9\u306E\u6982\u8981" },
            { "doclet.Fields", "\u30D5\u30A3\u30FC\u30EB\u30C9" },
            { "doclet.Fields_Declared_In_Class", "\u30AF\u30E9\u30B9\u3067\u5BA3\u8A00\u3055\u308C\u305F\u30D5\u30A3\u30FC\u30EB\u30C9" },
            { "doclet.Fields_Declared_In_Interface", "\u30A4\u30F3\u30BF\u30D5\u30A7\u30FC\u30B9\u3067\u5BA3\u8A00\u3055\u308C\u305F\u30D5\u30A3\u30FC\u30EB\u30C9" },
            { "doclet.Fields_Inherited_From_Class", "\u30AF\u30E9\u30B9\u304B\u3089\u7D99\u627F\u3055\u308C\u305F\u30D5\u30A3\u30FC\u30EB\u30C9" },
            { "doclet.Fields_Inherited_From_Interface", "\u30A4\u30F3\u30BF\u30D5\u30A7\u30FC\u30B9\u304B\u3089\u7D99\u627F\u3055\u308C\u305F\u30D5\u30A3\u30FC\u30EB\u30C9" },
            { "doclet.File_not_found", "\u30D5\u30A1\u30A4\u30EB\u304C\u898B\u3064\u304B\u308A\u307E\u305B\u3093: {0}" },
            { "doclet.From", "\u30C0\u30A6\u30F3\u30ED\u30FC\u30C9\u5143" },
            { "doclet.Generating_0", "{0}\u306E\u751F\u6210\u4E2D..." },
            { "doclet.Groupname_already_used", "-group\u30AA\u30D7\u30B7\u30E7\u30F3\u306B\u304A\u3044\u3066\u3001\u3059\u3067\u306B\u30B0\u30EB\u30FC\u30D7\u540D\u304C\u4F7F\u7528\u3055\u308C\u3066\u3044\u307E\u3059: {0}" },
            { "doclet.Implementation", "\u5B9F\u88C5:" },
            { "doclet.Indirect_Exports_Summary", "\u9593\u63A5\u7684\u30A8\u30AF\u30B9\u30DD\u30FC\u30C8" },
            { "doclet.Indirect_Opens_Summary", "\u9593\u63A5\u7684\u30AA\u30FC\u30D7\u30F3" },
            { "doclet.Indirect_Packages_Table_Summary", "{0}\u8868\u3001{1}\u306E\u30EA\u30B9\u30C8\u304A\u3088\u3073{2}" },
            { "doclet.Indirect_Requires_Summary", "\u9593\u63A5\u7684\u306B\u5FC5\u8981" },
            { "doclet.Instance_Methods", "\u30A4\u30F3\u30B9\u30BF\u30F3\u30B9\u30FB\u30E1\u30BD\u30C3\u30C9" },
            { "doclet.Interface", "\u30A4\u30F3\u30BF\u30D5\u30A7\u30FC\u30B9" },
            { "doclet.Interface_Summary", "\u30A4\u30F3\u30BF\u30D5\u30A7\u30FC\u30B9\u306E\u6982\u8981" },
            { "doclet.Interfaces", "\u30A4\u30F3\u30BF\u30D5\u30A7\u30FC\u30B9" },
            { "doclet.JavaScript_in_comment", "\u30C9\u30AD\u30E5\u30E1\u30F3\u30C8\u30FB\u30B3\u30E1\u30F3\u30C8\u306BJavaScript\u304C\u898B\u3064\u304B\u308A\u307E\u3057\u305F\u3002\n--allow-script-in-comments\u3092\u4F7F\u7528\u3057\u3066\u3001JavaScript\u306E\u4F7F\u7528\u3092\u8A31\u53EF\u3057\u3066\u304F\u3060\u3055\u3044\u3002" },
            { "doclet.JavaScript_in_option", "\u30AA\u30D7\u30B7\u30E7\u30F3{0}\u306BJavaScript\u304C\u542B\u307E\u308C\u3066\u3044\u307E\u3059\u3002\n--allow-script-in-comments\u3092\u4F7F\u7528\u3057\u3066\u3001JavaScript\u306E\u4F7F\u7528\u3092\u8A31\u53EF\u3057\u3066\u304F\u3060\u3055\u3044\u3002" },
            { "doclet.Member_Table_Summary", "{0}\u8868\u3001{1}\u306E\u30EA\u30B9\u30C8\u304A\u3088\u3073\u8AAC\u660E" },
            { "doclet.Members", "\u30E1\u30F3\u30D0\u30FC" },
            { "doclet.Method", "\u30E1\u30BD\u30C3\u30C9" },
            { "doclet.Method_Detail", "\u30E1\u30BD\u30C3\u30C9\u306E\u8A73\u7D30" },
            { "doclet.Method_Summary", "\u30E1\u30BD\u30C3\u30C9\u306E\u6982\u8981" },
            { "doclet.Methods", "\u30E1\u30BD\u30C3\u30C9" },
            { "doclet.Methods_Declared_In_Class", "\u30AF\u30E9\u30B9\u3067\u5BA3\u8A00\u3055\u308C\u305F\u30E1\u30BD\u30C3\u30C9" },
            { "doclet.Methods_Declared_In_Interface", "\u30A4\u30F3\u30BF\u30D5\u30A7\u30FC\u30B9\u3067\u5BA3\u8A00\u3055\u308C\u305F\u30E1\u30BD\u30C3\u30C9" },
            { "doclet.Methods_Inherited_From_Class", "\u30AF\u30E9\u30B9\u304B\u3089\u7D99\u627F\u3055\u308C\u305F\u30E1\u30BD\u30C3\u30C9" },
            { "doclet.Methods_Inherited_From_Interface", "\u30A4\u30F3\u30BF\u30D5\u30A7\u30FC\u30B9\u304B\u3089\u7D99\u627F\u3055\u308C\u305F\u30E1\u30BD\u30C3\u30C9" },
            { "doclet.MissingSerialDataTag", "\u30AF\u30E9\u30B9{0}\u306E\u30E1\u30BD\u30C3\u30C9{1}\u306B@serialData\u30BF\u30B0\u304C\u3042\u308A\u307E\u305B\u3093\u3002" },
            { "doclet.MissingSerialTag", "\u30AF\u30E9\u30B9{0}\u306E\u30C7\u30D5\u30A9\u30EB\u30C8\u306E\u76F4\u5217\u5316\u53EF\u80FD\u30D5\u30A3\u30FC\u30EB\u30C9{1}\u306E\u305F\u3081\u306E@serial\u30BF\u30B0\u304C\u3042\u308A\u307E\u305B\u3093\u3002" },
            { "doclet.Modifier", "\u4FEE\u98FE\u5B50" },
            { "doclet.Modifier_and_Type", "\u4FEE\u98FE\u5B50\u3068\u30BF\u30A4\u30D7" },
            { "doclet.Module_Summary", "\u30E2\u30B8\u30E5\u30FC\u30EB\u306E\u6982\u8981" },
            { "doclet.Modules", "\u30E2\u30B8\u30E5\u30FC\u30EB" },
            { "doclet.Nested_Class_Summary", "\u30CD\u30B9\u30C8\u3055\u308C\u305F\u30AF\u30E9\u30B9\u306E\u6982\u8981" },
            { "doclet.Nested_Classes", "\u30CD\u30B9\u30C8\u3055\u308C\u305F\u30AF\u30E9\u30B9" },
            { "doclet.Nested_Classes_Interfaces_Declared_In_Class", "\u30AF\u30E9\u30B9\u3067\u5BA3\u8A00\u3055\u308C\u305F\u30CD\u30B9\u30C8\u3055\u308C\u305F\u30AF\u30E9\u30B9/\u30A4\u30F3\u30BF\u30D5\u30A7\u30FC\u30B9" },
            { "doclet.Nested_Classes_Interfaces_Declared_In_Interface", "\u30A4\u30F3\u30BF\u30D5\u30A7\u30FC\u30B9\u3067\u5BA3\u8A00\u3055\u308C\u305F\u30CD\u30B9\u30C8\u3055\u308C\u305F\u30AF\u30E9\u30B9/\u30A4\u30F3\u30BF\u30D5\u30A7\u30FC\u30B9" },
            { "doclet.Nested_Classes_Interfaces_Inherited_From_Class", "\u30AF\u30E9\u30B9\u304B\u3089\u7D99\u627F\u3055\u308C\u305F\u30CD\u30B9\u30C8\u3055\u308C\u305F\u30AF\u30E9\u30B9/\u30A4\u30F3\u30BF\u30D5\u30A7\u30FC\u30B9" },
            { "doclet.Nested_Classes_Interfaces_Inherited_From_Interface", "\u30A4\u30F3\u30BF\u30D5\u30A7\u30FC\u30B9\u304B\u3089\u7D99\u627F\u3055\u308C\u305F\u30CD\u30B9\u30C8\u3055\u308C\u305F\u30AF\u30E9\u30B9/\u30A4\u30F3\u30BF\u30D5\u30A7\u30FC\u30B9" },
            { "doclet.No_Public_Classes_To_Document", "\u30C9\u30AD\u30E5\u30E1\u30F3\u30C8\u5316\u3059\u308Bpublic\u307E\u305F\u306Fprotected\u30AF\u30E9\u30B9\u304C\u898B\u3064\u304B\u308A\u307E\u305B\u3093\u3002" },
            { "doclet.Notice_taglet_conflict_warn", "\u30CE\u30FC\u30C8: \u6A19\u6E96\u30BF\u30B0\u3092\u30AA\u30FC\u30D0\u30FC\u30E9\u30A4\u30C9\u3059\u308B\u53EF\u80FD\u6027\u306E\u3042\u308B\u30AB\u30B9\u30BF\u30E0\u30FB\u30BF\u30B0: {0}\u3002\u30AA\u30FC\u30D0\u30FC\u30E9\u30A4\u30C9\u3092\u907F\u3051\u308B\u305F\u3081\u306B\u3001\u30AB\u30B9\u30BF\u30E0\u30FB\u30BF\u30B0\u540D\u306E\u4E2D\u306B\u5C11\u306A\u304F\u3068\u30821\u3064\u306E\u30D4\u30EA\u30AA\u30C9(.)\u3092\u4F7F\u7528\u3057\u3066\u304F\u3060\u3055\u3044\u3002" },
            { "doclet.Notice_taglet_overriden", "\u30CE\u30FC\u30C8: \u6A19\u6E96\u30BF\u30B0\u3092\u30AA\u30FC\u30D0\u30FC\u30E9\u30A4\u30C9\u3059\u308B\u30AB\u30B9\u30BF\u30E0\u30FB\u30BF\u30B0: {0}" },
            { "doclet.Notice_taglet_registered", "\u767B\u9332\u3055\u308C\u305F\u30BF\u30B0\u30EC\u30C3\u30C8{0} ..." },
            { "doclet.Notice_taglet_unseen", "\u30CE\u30FC\u30C8: \u975E\u8868\u793A\u306E\u30AB\u30B9\u30BF\u30E0\u30FB\u30BF\u30B0: {0}" },
            { "doclet.OpenedTo", "\u30E2\u30B8\u30E5\u30FC\u30EB\u306B\u30AA\u30FC\u30D7\u30F3" },
            { "doclet.Opened_Packages_Summary", "\u30AA\u30FC\u30D7\u30F3" },
            { "doclet.Option_conflict", "\u30AA\u30D7\u30B7\u30E7\u30F3{0}\u304C{1}\u3068\u77DB\u76FE\u3057\u307E\u3059" },
            { "doclet.Option_doclint_invalid_arg", "-Xdoclint\u30AA\u30D7\u30B7\u30E7\u30F3\u306E\u5F15\u6570\u304C\u7121\u52B9\u3067\u3059" },
            { "doclet.Option_doclint_no_qualifiers", "\u30A2\u30AF\u30BB\u30B9\u4FEE\u98FE\u5B50\u306F-Xdoclint\u306E\u5F15\u6570\u306B\u4F7F\u7528\u3067\u304D\u307E\u305B\u3093" },
            { "doclet.Option_doclint_package_invalid_arg", "-Xdoclint/package\u30AA\u30D7\u30B7\u30E7\u30F3\u306E\u5F15\u6570\u304C\u7121\u52B9\u3067\u3059" },
            { "doclet.Option_invalid", "{1}\u30AA\u30D7\u30B7\u30E7\u30F3\u306E\u5F15\u6570{0}\u304C\u7121\u52B9\u3067\u3059" },
            { "doclet.Option_reuse", "\u30AA\u30D7\u30B7\u30E7\u30F3\u304C\u518D\u4F7F\u7528\u3055\u308C\u3066\u3044\u307E\u3059: {0}" },
            { "doclet.Other_Modules", "\u305D\u306E\u4ED6\u306E\u30E2\u30B8\u30E5\u30FC\u30EB" },
            { "doclet.Other_Packages", "\u305D\u306E\u4ED6\u306E\u30D1\u30C3\u30B1\u30FC\u30B8" },
            { "doclet.Package_Summary", "\u30D1\u30C3\u30B1\u30FC\u30B8\u306E\u6982\u8981" },
            { "doclet.Package_class_and_interface_descriptions", "\u30D1\u30C3\u30B1\u30FC\u30B8\u3001\u30AF\u30E9\u30B9\u304A\u3088\u3073\u30A4\u30F3\u30BF\u30D5\u30A7\u30FC\u30B9\u306E\u8AAC\u660E" },
            { "doclet.Package_private", "(package private)" },
            { "doclet.Packages", "\u30D1\u30C3\u30B1\u30FC\u30B8" },
            { "doclet.Packages_Summary", "\u30D1\u30C3\u30B1\u30FC\u30B8" },
            { "doclet.Parameters", "\u30D1\u30E9\u30E1\u30FC\u30BF:" },
            { "doclet.Parameters_dup_warn", "\u30D1\u30E9\u30E1\u30FC\u30BF\"{0}\"\u304C2\u56DE\u4EE5\u4E0A\u30C9\u30AD\u30E5\u30E1\u30F3\u30C8\u5316\u3055\u308C\u3066\u3044\u307E\u3059\u3002" },
            { "doclet.Parameters_warn", "@param argument \"{0}\"\u306F\u30D1\u30E9\u30E1\u30FC\u30BF\u540D\u3067\u306F\u3042\u308A\u307E\u305B\u3093\u3002" },
            { "doclet.Properties", "\u30D7\u30ED\u30D1\u30C6\u30A3" },
            { "doclet.Properties_Declared_In_Class", "\u30AF\u30E9\u30B9\u3067\u5BA3\u8A00\u3055\u308C\u305F\u30D7\u30ED\u30D1\u30C6\u30A3" },
            { "doclet.Properties_Declared_In_Interface", "\u30A4\u30F3\u30BF\u30D5\u30A7\u30FC\u30B9\u3067\u5BA3\u8A00\u3055\u308C\u305F\u30D7\u30ED\u30D1\u30C6\u30A3" },
            { "doclet.Properties_Inherited_From_Class", "\u30AF\u30E9\u30B9\u304B\u3089\u7D99\u627F\u3055\u308C\u305F\u30D7\u30ED\u30D1\u30C6\u30A3" },
            { "doclet.Properties_Inherited_From_Interface", "\u30A4\u30F3\u30BF\u30D5\u30A7\u30FC\u30B9\u304B\u3089\u7D99\u627F\u3055\u308C\u305F\u30D7\u30ED\u30D1\u30C6\u30A3" },
            { "doclet.Property", "\u30D7\u30ED\u30D1\u30C6\u30A3" },
            { "doclet.PropertyDescription", "\u30D7\u30ED\u30D1\u30C6\u30A3\u306E\u8AAC\u660E:" },
            { "doclet.PropertyGetter", "\u30D7\u30ED\u30D1\u30C6\u30A3\u306E\u5024\u3092\u53D6\u5F97\u3057\u307E\u3059" },
            { "doclet.PropertyGetterWithName", "\u30D7\u30ED\u30D1\u30C6\u30A3{0}\u306E\u5024\u3092\u53D6\u5F97\u3057\u307E\u3059\u3002" },
            { "doclet.PropertySetter", "\u30D7\u30ED\u30D1\u30C6\u30A3\u306E\u5024\u3092\u8A2D\u5B9A\u3057\u307E\u3059" },
            { "doclet.PropertySetterWithName", "\u30D7\u30ED\u30D1\u30C6\u30A3{0}\u306E\u5024\u3092\u8A2D\u5B9A\u3057\u307E\u3059\u3002" },
            { "doclet.Property_Detail", "\u30D7\u30ED\u30D1\u30C6\u30A3\u306E\u8A73\u7D30" },
            { "doclet.Property_Summary", "\u30D7\u30ED\u30D1\u30C6\u30A3\u306E\u6982\u8981" },
            { "doclet.Provides_Summary", "\u63D0\u4F9B" },
            { "doclet.Requires_Summary", "\u5FC5\u8981" },
            { "doclet.Return_tag_on_void_method", "\u623B\u308A\u5024\u306E\u578B\u304Cvoid\u306E\u30E1\u30BD\u30C3\u30C9\u3067\u306F@return\u30BF\u30B0\u3092\u4F7F\u7528\u3067\u304D\u307E\u305B\u3093\u3002" },
            { "doclet.Returns", "\u623B\u308A\u5024:" },
            { "doclet.SearchTags", "SearchTags" },
            { "doclet.See", "\u53C2\u7167\u5148:" },
            { "doclet.See_Also", "\u95A2\u9023\u9805\u76EE:" },
            { "doclet.SerialData", "\u30B7\u30EA\u30A2\u30EB\u30FB\u30C7\u30FC\u30BF:" },
            { "doclet.Serializable_no_customization", "readObject\u307E\u305F\u306FwriteObject\u30E1\u30BD\u30C3\u30C9\u304C\u5BA3\u8A00\u3055\u308C\u3066\u3044\u307E\u305B\u3093\u3002" },
            { "doclet.Serialized_Form", "\u76F4\u5217\u5316\u3055\u308C\u305F\u5F62\u5F0F" },
            { "doclet.Serialized_Form_class", "\u76F4\u5217\u5316\u306E\u6982\u8981" },
            { "doclet.Serialized_Form_fields", "\u76F4\u5217\u5316\u3055\u308C\u305F\u30D5\u30A3\u30FC\u30EB\u30C9" },
            { "doclet.Serialized_Form_methods", "\u76F4\u5217\u5316\u30E1\u30BD\u30C3\u30C9" },
            { "doclet.Services", "\u30B5\u30FC\u30D3\u30B9" },
            { "doclet.Since", "\u5C0E\u5165\u3055\u308C\u305F\u30D0\u30FC\u30B8\u30E7\u30F3:" },
            { "doclet.Static_Methods", "static\u30E1\u30BD\u30C3\u30C9" },
            { "doclet.Throws", "\u4F8B\u5916:" },
            { "doclet.Toolkit_Usage_Violation", "\u30C9\u30C3\u30AF\u30EC\u30C3\u30C8\u30FB\u30C4\u30FC\u30EB\u30FB\u30AD\u30C3\u30C8\u306F{0}\u306B\u3088\u3063\u3066\u306E\u307F\u4F7F\u7528\u3055\u308C\u307E\u3059" },
            { "doclet.Type", "\u30BF\u30A4\u30D7" },
            { "doclet.TypeParameters", "\u578B\u30D1\u30E9\u30E1\u30FC\u30BF:" },
            { "doclet.Type_Parameters_dup_warn", "\u578B\u30D1\u30E9\u30E1\u30FC\u30BF\"{0}\"\u304C2\u56DE\u4EE5\u4E0A\u30C9\u30AD\u30E5\u30E1\u30F3\u30C8\u5316\u3055\u308C\u3066\u3044\u307E\u3059\u3002" },
            { "doclet.Type_Parameters_warn", "@param argument \"{0}\"\u306F\u578B\u30D1\u30E9\u30E1\u30FC\u30BF\u540D\u3067\u306F\u3042\u308A\u307E\u305B\u3093\u3002" },
            { "doclet.Types", "\u30BF\u30A4\u30D7" },
            { "doclet.UnknownTag", "{0}\u306F\u4E0D\u660E\u306A\u30BF\u30B0\u3067\u3059\u3002" },
            { "doclet.UnknownTagLowercase", "{0}\u306F\u4E0D\u660E\u306A\u30BF\u30B0\u3067\u3059\u3002\u5927\u6587\u5B57\u3068\u5C0F\u6587\u5B57\u306E\u533A\u5225\u3092\u9664\u3044\u3066\u306F\u65E2\u77E5\u306E\u30BF\u30B0\u3068\u540C\u3058\u3067\u3059\u3002" },
            { "doclet.Use_Table_Summary", "\u8868\u3001{0}\u306E\u30EA\u30B9\u30C8\u304A\u3088\u3073\u8AAC\u660E\u306E\u4F7F\u7528" },
            { "doclet.Uses_Summary", "\u4F7F\u7528" },
            { "doclet.Value", "\u5024" },
            { "doclet.Version", "\u30D0\u30FC\u30B8\u30E7\u30F3:" },
            { "doclet.annotation_type_optional_members", "\u4EFB\u610F\u8981\u7D20" },
            { "doclet.annotation_type_required_members", "\u5FC5\u9808\u8981\u7D20" },
            { "doclet.annotationtype", "\u6CE8\u91C8\u578B" },
            { "doclet.annotationtypes", "\u6CE8\u91C8\u578B" },
            { "doclet.class", "\u30AF\u30E9\u30B9" },
            { "doclet.classes", "\u30AF\u30E9\u30B9" },
            { "doclet.constructors", "\u30B3\u30F3\u30B9\u30C8\u30E9\u30AF\u30BF" },
            { "doclet.dest_dir_create", "\u5B9B\u5148\u30C7\u30A3\u30EC\u30AF\u30C8\u30EA\u306E\u4F5C\u6210\u4E2D: \"{0}\"" },
            { "doclet.destination_directory_not_directory_0", "\u8EE2\u9001\u5148\u30C7\u30A3\u30EC\u30AF\u30C8\u30EA\u306F\u30C7\u30A3\u30EC\u30AF\u30C8\u30EA\u3067\u306F\u3042\u308A\u307E\u305B\u3093: {0}" },
            { "doclet.destination_directory_not_writable_0", "\u8EE2\u9001\u5148\u30C7\u30A3\u30EC\u30AF\u30C8\u30EA\u306F\u66F8\u8FBC\u307F\u53EF\u80FD\u3067\u306F\u3042\u308A\u307E\u305B\u3093: {0}" },
            { "doclet.enum", "\u5217\u6319" },
            { "doclet.enum_constants", "\u5217\u6319\u578B\u5B9A\u6570" },
            { "doclet.enum_valueof_doc.fullbody", "\u6307\u5B9A\u3057\u305F\u540D\u524D\u3092\u6301\u3064\u3053\u306E\u578B\u306E\u5217\u6319\u578B\u5B9A\u6570\u3092\u8FD4\u3057\u307E\u3059\u3002\n\u6587\u5B57\u5217\u306F\u3001\u3053\u306E\u578B\u306E\u5217\u6319\u578B\u5B9A\u6570\u3092\u5BA3\u8A00\u3059\u308B\u306E\u306B\u4F7F\u7528\u3057\u305F\u8B58\u5225\u5B50\u3068<i>\u6B63\u78BA\u306B</i>\n\u4E00\u81F4\u3057\u3066\u3044\u308B\u5FC5\u8981\u304C\u3042\u308A\u307E\u3059\u3002(\u4F59\u5206\u306A\u7A7A\u767D\u6587\u5B57\u3092\u542B\u3081\u308B\u3053\u3068\u306F\n\u3067\u304D\u307E\u305B\u3093\u3002)" },
            { "doclet.enum_valueof_doc.param_name", "\u8FD4\u3055\u308C\u308B\u5217\u6319\u578B\u5B9A\u6570\u306E\u540D\u524D\u3002" },
            { "doclet.enum_valueof_doc.return", "\u6307\u5B9A\u3057\u305F\u540D\u524D\u306E\u5217\u6319\u578B\u5B9A\u6570" },
            { "doclet.enum_valueof_doc.throws_ila", "\u3053\u306E\u5217\u6319\u578B\u306B\u3001\u6307\u5B9A\u3057\u305F\u540D\u524D\u306E\u5B9A\u6570\u304C\u306A\u3044\u5834\u5408" },
            { "doclet.enum_valueof_doc.throws_npe", "\u5F15\u6570\u304Cnull\u306E\u5834\u5408" },
            { "doclet.enum_values_doc.fullbody", "\u3053\u306E\u5217\u6319\u578B\u306E\u5B9A\u6570\u3092\u542B\u3080\u914D\u5217\u3092\u5BA3\u8A00\u3055\u308C\u3066\u3044\u308B\u9806\u5E8F\u3067\u8FD4\u3057\u307E\u3059\u3002\n\u3053\u306E\u30E1\u30BD\u30C3\u30C9\u306F\u6B21\u306E\u3088\u3046\u306B\u3057\u3066\u5B9A\u6570\u3092\u53CD\u5FA9\u3059\u308B\u305F\u3081\u306B\n\u4F7F\u7528\u3067\u304D\u307E\u3059:\n<pre>\nfor ({0} c : {0}.values())\n&nbsp;   System.out.println(c);\n</pre>" },
            { "doclet.enum_values_doc.return", "\u3053\u306E\u5217\u6319\u578B\u306E\u5B9A\u6570\u3092\u542B\u3080\u3001\u5BA3\u8A00\u3055\u308C\u3066\u3044\u308B\u9806\u5E8F\u3067\u306E\u914D\u5217" },
            { "doclet.enums", "\u5217\u6319" },
            { "doclet.error", "\u30A8\u30E9\u30FC" },
            { "doclet.error.initializing.dest.dir", "\u8EE2\u9001\u5148\u30C7\u30A3\u30EC\u30AF\u30C8\u30EA\u306E\u521D\u671F\u5316\u4E2D\u306B\u30A8\u30E9\u30FC\u304C\u767A\u751F\u3057\u307E\u3057\u305F: {0}" },
            { "doclet.errors", "\u30A8\u30E9\u30FC" },
            { "doclet.exception", "\u4F8B\u5916" },
            { "doclet.exception.read.file", "\u30D5\u30A1\u30A4\u30EB\u306E\u8AAD\u53D6\u308A\u4E2D\u306B\u30A8\u30E9\u30FC\u304C\u767A\u751F\u3057\u307E\u3057\u305F: {0}\n\t({1})" },
            { "doclet.exception.read.resource", "\u30B7\u30B9\u30C6\u30E0\u30FB\u30EA\u30BD\u30FC\u30B9\u306E\u8AAD\u53D6\u308A\u4E2D\u306B\u30A8\u30E9\u30FC\u304C\u767A\u751F\u3057\u307E\u3057\u305F: {0}\n\t({1})" },
            { "doclet.exception.write.file", "\u30D5\u30A1\u30A4\u30EB\u306E\u66F8\u8FBC\u307F\u4E2D\u306B\u30A8\u30E9\u30FC\u304C\u767A\u751F\u3057\u307E\u3057\u305F: {0}\n\t({1})" },
            { "doclet.exceptions", "\u4F8B\u5916" },
            { "doclet.fields", "\u30D5\u30A3\u30FC\u30EB\u30C9" },
            { "doclet.in", "{1}\u306E{0}" },
            { "doclet.interface", "\u30A4\u30F3\u30BF\u30D5\u30A7\u30FC\u30B9" },
            { "doclet.interfaces", "\u30A4\u30F3\u30BF\u30D5\u30A7\u30FC\u30B9" },
            { "doclet.internal.exception", "\u5185\u90E8\u4F8B\u5916\u304C\u767A\u751F\u3057\u307E\u3057\u305F\u3002 \n\t({0})" },
            { "doclet.internal.report.bug", "Bug Database (http://bugs.java.com)\u3067\u91CD\u8907\u304C\u306A\u3044\u304B\u3092\u3054\u78BA\u8A8D\u306E\u3046\u3048\u3001Java bug\u30EC\u30DD\u30FC\u30C8\u30FB\u30DA\u30FC\u30B8\n(http://bugreport.java.com)\u3067javadoc\u30C4\u30FC\u30EB\u306B\u5BFE\u3059\u308Bbug\u306E\u767B\u9332\u3092\u304A\u9858\u3044\u3044\u305F\u3057\u307E\u3059\u3002\n\u30EC\u30DD\u30FC\u30C8\u306B\u306F\u3001\u30A8\u30E9\u30FC\u30FB\u30E1\u30C3\u30BB\u30FC\u30B8\u3068\u6B21\u306E\u8A3A\u65AD\u5185\u5BB9\u3092\u542B\u3081\u3066\u304F\u3060\u3055\u3044\u3002\u3054\u5354\u529B\u3042\u308A\u304C\u3068\u3046\u3054\u3056\u3044\u307E\u3059\u3002" },
            { "doclet.linkMismatch_ModuleLinkedtoPackage", "\u30C9\u30AD\u30E5\u30E1\u30F3\u30C8\u5316\u3057\u3088\u3046\u3068\u3057\u3066\u3044\u308B\u30B3\u30FC\u30C9\u3067\u306F\u30E2\u30B8\u30E5\u30FC\u30EB\u304C\u4F7F\u7528\u3055\u308C\u3066\u3044\u307E\u3059\u304C\u3001{0}\u3067\u5B9A\u7FA9\u3055\u308C\u3066\u3044\u308B\u30D1\u30C3\u30B1\u30FC\u30B8\u306F\u540D\u524D\u306E\u306A\u3044\u30E2\u30B8\u30E5\u30FC\u30EB\u306E\u3082\u306E\u3067\u3059\u3002" },
            { "doclet.linkMismatch_PackagedLinkedtoModule", "\u30C9\u30AD\u30E5\u30E1\u30F3\u30C8\u5316\u3057\u3088\u3046\u3068\u3057\u3066\u3044\u308B\u30B3\u30FC\u30C9\u3067\u306F\u540D\u524D\u306E\u306A\u3044\u30E2\u30B8\u30E5\u30FC\u30EB\u306E\u30D1\u30C3\u30B1\u30FC\u30B8\u304C\u4F7F\u7528\u3055\u308C\u3066\u3044\u307E\u3059\u304C\u3001{0}\u3067\u5B9A\u7FA9\u3055\u308C\u3066\u3044\u308B\u30D1\u30C3\u30B1\u30FC\u30B8\u306F\u540D\u524D\u306E\u3042\u308B\u30E2\u30B8\u30E5\u30FC\u30EB\u306E\u3082\u306E\u3067\u3059\u3002" },
            { "doclet.methods", "\u30E1\u30BD\u30C3\u30C9" },
            { "doclet.modules", "\u30E2\u30B8\u30E5\u30FC\u30EB" },
            { "doclet.nested_classes", "\u30CD\u30B9\u30C8\u3055\u308C\u305F\u30AF\u30E9\u30B9" },
            { "doclet.noInheritedDoc", "@inheritDoc\u304C\u4F7F\u7528\u3055\u308C\u3066\u3044\u307E\u3059\u304C\u3001{0}\u306F\u3069\u306E\u30E1\u30BD\u30C3\u30C9\u3082\u30AA\u30FC\u30D0\u30FC\u30E9\u30A4\u30C9\u307E\u305F\u306F\u5B9F\u88C5\u3057\u3066\u3044\u307E\u305B\u3093\u3002" },
            { "doclet.packages", "\u30D1\u30C3\u30B1\u30FC\u30B8" },
            { "doclet.properties", "\u30D7\u30ED\u30D1\u30C6\u30A3" },
            { "doclet.search", "SEARCH:" },
            { "doclet.sourcetab_warning", "-sourcetab\u306E\u5F15\u6570\u306F0\u3088\u308A\u5927\u304D\u3044\u6574\u6570\u3067\u3042\u308B\u5FC5\u8981\u304C\u3042\u308A\u307E\u3059\u3002" },
            { "doclet.subclasses", "\u30B5\u30D6\u30AF\u30E9\u30B9" },
            { "doclet.subinterfaces", "\u30B5\u30D6\u30A4\u30F3\u30BF\u30D5\u30A7\u30FC\u30B9" },
            { "doclet.tag_misuse", "{0}\u30BF\u30B0\u306F{1}\u30C9\u30AD\u30E5\u30E1\u30F3\u30C8\u5185\u3067\u306F\u4F7F\u7528\u3067\u304D\u307E\u305B\u3093\u3002\u4F7F\u7528\u3067\u304D\u308B\u306E\u306F\u6B21\u306E\u30BF\u30A4\u30D7\u306E\u30C9\u30AD\u30E5\u30E1\u30F3\u30C8\u5185\u306E\u307F\u3067\u3059: {2}\u3002" },
            { "doclet.types", "\u30BF\u30A4\u30D7" },
            { "doclet.value_tag_invalid_constant", "@value\u30BF\u30B0({0}\u3092\u53C2\u7167\u3057\u3066\u3044\u308B)\u306F\u5B9A\u6570\u5185\u3067\u306E\u307F\u4F7F\u7528\u3067\u304D\u307E\u3059\u3002" },
            { "doclet.value_tag_invalid_reference", "{0}(@value\u30BF\u30B0\u306B\u3088\u308A\u53C2\u7167\u3055\u308C\u3066\u3044\u308B)\u306F\u4E0D\u660E\u306A\u53C2\u7167\u3067\u3059\u3002" },
            { "doclet.value_tag_invalid_use", "@value\u30BF\u30B0\u306F\u3053\u3053\u3067\u306F\u4F7F\u7528\u3067\u304D\u307E\u305B\u3093\u3002" },
        };
    }
}
